@@ -541,7 +541,7 @@ e_book_backend_exchange_connect (EBookBackendExchange *be)
 	char *date_prop, *access_prop;
 	int access;
 	E2kResult *results;
-	int nresults;
+	int nresults = 0;
 	E2kHTTPStatus status;
 	time_t folder_mtime;
 
@@ -575,6 +575,8 @@ e_book_backend_exchange_connect (EBookBackendExchange *be)
 
 	if (!(access & MAPI_ACCESS_READ)) {
 		bepriv->connected = FALSE;
+		if (nresults)
+			e2k_results_free (results, nresults);
 		return GNOME_Evolution_Addressbook_PermissionDenied;
 	}
 
@@ -616,8 +618,6 @@ e_book_backend_exchange_connect (EBookBackendExchange *be)
 	else
 		folder_mtime = 0;
 
-	e2k_results_free (results, nresults);
-
 	/* open the summary file */
 	summary_path = e_folder_exchange_get_storage_file (bepriv->folder, "summary");
 
@@ -637,6 +637,8 @@ e_book_backend_exchange_connect (EBookBackendExchange *be)
 
 	bepriv->connected = TRUE;
 	e_book_backend_set_is_loaded (E_BOOK_BACKEND (be), TRUE);
+	if (nresults)
+		e2k_results_free (results, nresults);
 	return GNOME_Evolution_Addressbook_Success;
 }
 
@@ -824,15 +826,22 @@ proppatch_date (PropMapping *prop_mapping,
 		return;
 	}
 
-	memset (&then, 0, sizeof(then));
-	then.tm_year = new_dt->year - 1900;
-	then.tm_mon  = new_dt->month - 1;
-	then.tm_mday = new_dt->day;
-	then.tm_isdst = -1;
-	tt = mktime (&then);
+	if (new_dt) {
+		memset (&then, 0, sizeof(then));
+		then.tm_year = new_dt->year - 1900;
+		then.tm_mon  = new_dt->month - 1;
+		then.tm_mday = new_dt->day;
+		then.tm_isdst = -1;
+		tt = mktime (&then);
 
-	e2k_properties_set_date (props, prop_mapping->prop_name,
-				 e2k_make_timestamp (tt));
+		e2k_properties_set_date (props, prop_mapping->prop_name,
+					 e2k_make_timestamp (tt));
+	}
+	else {
+		/* remove the dates set */
+		e2k_properties_set_date (props, prop_mapping->prop_name,
+					 e2k_make_timestamp (time (NULL)));
+	}
 	e_contact_date_free (new_dt);
 }
 
@@ -964,7 +973,6 @@ proppatch_address (PropMapping *prop_mapping,
 		} else
 			value = g_strdup (new_addrprops[i]);
 		e2k_properties_set_string (props, propnames[i], value);
-		g_free (value);
 	}
 
 	e_contact_address_free (new_address);
@@ -1361,7 +1369,7 @@ e_book_backend_exchange_modify_contact (EBookBackendSync  *backend,
 	const char *uri;
 	E2kHTTPStatus status;
 	E2kResult *results;
-	int nresults;
+	int nresults = 0;
 	E2kProperties *props;
 
 	d(printf("ebbe_modify_contact(%p, %p, %s)\n", backend, book, vcard));
@@ -1439,6 +1447,9 @@ e_book_backend_exchange_modify_contact (EBookBackendSync  *backend,
 		if (old_contact)
 			g_object_unref (old_contact);
 
+		if (nresults)
+			e2k_results_free (results, nresults);
+
 		if (E2K_HTTP_STATUS_IS_SUCCESSFUL (status)) {
 			e_book_backend_summary_remove_contact (bepriv->summary,
 							       uri);
@@ -1858,6 +1869,11 @@ e_book_backend_exchange_start_book_view (EBookBackend  *backend,
 	switch (bepriv->mode) {
 
 	case GNOME_Evolution_Addressbook_MODE_LOCAL:
+		if (!bepriv->marked_for_offline) {
+			e_data_book_view_notify_complete (book_view, 
+					GNOME_Evolution_Addressbook_OfflineUnavailable);
+			return;
+		}
 		if (!bepriv->cache) {
 			e_data_book_view_notify_complete (book_view, 
 					GNOME_Evolution_Addressbook_Success);
@@ -2136,6 +2152,7 @@ e_book_backend_exchange_authenticate_user (EBookBackend *backend,
 		account = exchange_component_get_account_for_uri (global_exchange_component, NULL);
 		/* FIXME : Check for failures */
 		if (!exchange_account_get_context (account)) {
+			exchange_account_set_online (account);
 			if(!exchange_account_connect (account, password, &result)) {
 				e_data_book_respond_authenticate_user (book, opid, GNOME_Evolution_Addressbook_AuthenticationFailed);
 				return;
@@ -2281,16 +2298,6 @@ e_book_backend_exchange_load_source (EBookBackend *backend,
 	e_book_backend_set_is_loaded (E_BOOK_BACKEND (be), TRUE);
 	e_book_backend_notify_connection_status (E_BOOK_BACKEND (be), TRUE);
 
-	if (e_book_backend_cache_is_populated (bepriv->cache)) {
-		if (bepriv->is_writable)
-			g_thread_create ((GThreadFunc) update_cache, 
-					  be, FALSE, NULL);
-	}
-	else if (bepriv->is_writable || bepriv->marked_for_offline){ 
-		/* for personal books we always cache*/
-		g_thread_create ((GThreadFunc) build_cache, be, FALSE, NULL);
-	}
-
 	return GNOME_Evolution_Addressbook_Success;
 }
 
